@@ -1,11 +1,11 @@
 package Indent::Word;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Class::Utils qw(set_params);
+use English qw(-no_match_vars);
+use Error::Pure qw(err);
 use Indent::Utils qw(line_size_check);
 use Readonly;
 
@@ -13,14 +13,16 @@ use Readonly;
 Readonly::Scalar my $EMPTY_STR => q{};
 Readonly::Scalar my $LINE_SIZE => 79;
 
-# Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Constructor.
 sub new {
 	my ($class, @params) = @_;
 	my $self = bless {}, $class;
 
+	# Use with ANSI sequences.
+	$self->{'ansi'} = 0;
+
 	# Options.
 	$self->{'line_size'} = $LINE_SIZE;
 	$self->{'next_indent'} = "\t";
@@ -34,6 +36,16 @@ sub new {
 	# 'line_size' check.
 	line_size_check($self);
 
+	# Check rutine for removing ANSI sequences.
+	if ($self->{'ansi'}) {
+		eval {
+			require Text::ANSI::Util;
+		};
+		if ($EVAL_ERROR) {
+			err "Cannot load 'Text::ANSI::Util' module.";
+		}
+	}
+
 	# Object.
 	return $self;
 }
@@ -56,20 +68,20 @@ sub indent {
 	my $last_second_length = 0;
 	my @data;
 	my $one = 1;
-	while (length $second >= $self->{'line_size'}
+	while ($self->_length($second) >= $self->{'line_size'}
 		&& $second =~ /^\s*\S+\s+/ms
-		&& $last_second_length != length $second) {
+		&& $last_second_length != $self->_length($second)) {
 
 		# Last length of non-parsed part of data.
-		$last_second_length = length $second;
+		$last_second_length = $self->_length($second);
 
 		# Parse to indent length.
-		($first, my $tmp) = $second
-			=~ /^(.{0,$self->{'line_size'}})\s+(.*)$/msx;
+		($first, my $tmp) = $self->_parse_to_indent_length($second);
 
 		# If string is non-breakable in indent length, than parse to
 		# blank char.
-		if (! $first || length $first < length $indent
+		if (! $first
+			|| $self->_length($first) < $self->_length($indent)
 			|| $first =~ /^$indent\s*$/ms) {
 
 			($first, $tmp) = $second
@@ -104,6 +116,43 @@ sub indent {
 	return wantarray ? @data : join($self->{'output_separator'}, @data);
 }
 
+# Get length.
+sub _length {
+	my ($self, $string) = @_;
+	if ($self->{'ansi'}) {
+		return length Text::ANSI::Util::ta_strip($string);
+	} else {
+		return length $string;
+	}
+}
+
+# Parse to indent length.
+sub _parse_to_indent_length {
+	my ($self, $string) = @_;
+	my @ret;
+	if ($self->{'ansi'}) {
+		my $string_wo_ansi = Text::ANSI::Util::ta_strip($string);
+
+		# First part.
+		my ($first_wo_ansi) = $string_wo_ansi
+			=~ m/^(.{0,$self->{'line_size'}})\s+(.*)$/msx;
+		push @ret, Text::ANSI::Util::ta_trunc($string, length $first_wo_ansi);
+
+		# Second part. (Remove first part + whitespace from string.)
+		my $other_string_wo_ansi = Text::ANSI::Util::ta_strip(
+			Text::ANSI::Util::ta_substr($string, length $first_wo_ansi,
+				Text::ANSI::Util::ta_length($string))
+		);
+		$other_string_wo_ansi =~ m/^(\s*)/ms;
+		my $count_of_spaces = length $1;
+		push @ret, Text::ANSI::Util::ta_substr($string, 0, (length $first_wo_ansi)
+			+ $count_of_spaces, '');
+	} else {
+		@ret = $string =~ m/^(.{0,$self->{'line_size'}})\s+(.*)$/msx;
+	}
+	return @ret;
+}
+
 1;
 
 __END__
@@ -132,6 +181,11 @@ __END__
 
 =over 8
 
+=item * C<ansi>
+
+ Use with ANSI sequences.
+ Default value is 0.
+
 =item * C<line_size>
 
  Sets indent line size value.
@@ -160,19 +214,18 @@ __END__
 =head1 ERRORS
 
  new():
+         Cannot load 'Text::ANSI::Util' module.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
          From Indent::Utils::line_size_check():
                  'line_size' parameter must be a positive number.
                          line_size => %s
 
-=head1 EXAMPLE
+=head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Indent::Word;
 
  # Object.
@@ -187,18 +240,67 @@ __END__
  # text text text text
  # <--tab->text text text
 
+=head1 EXAMPLE2
+
+ use strict;
+ use warnings;
+
+ use Indent::Word;
+ use Term::ANSIColor;
+
+ # Object.
+ my $i = Indent::Word->new(
+         'ansi' => 1,
+         'line_size' => 20,
+ );
+
+ # Indent.
+ print $i->indent('text text '.color('cyan').'text'.color('reset').
+         ' text '.color('red').'text'.color('reset').' text text')."\n";
+
+ # Output:
+ # text text text text
+ # <--tab->text text text
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
+L<English>,
+L<Error::Pure>,
 L<Indent::Utils>,
 L<Readonly>.
 
+L<Text::ANSI::Util> for situation with 'ansi' => 1.
+
 =head1 SEE ALSO
 
-L<Indent>,
-L<Indent::Block>,
-L<Indent::Data>,
-L<Indent::Utils>.
+=over
+
+=item L<Indent>
+
+Class for indent handling.
+
+=item L<Indent::Block>
+
+Class for block indenting.
+
+=item L<Indent::Data>
+
+Class for data indenting.
+
+=item L<Indent::String>
+
+Class for text indenting.
+
+=item L<Indent::Utils>
+
+Utilities for Indent classes.
+
+=item L<Text::Wrap>
+
+line wrapping to form simple paragraphs
+
+=back
 
 =head1 REPOSITORY
 
@@ -206,16 +308,17 @@ L<https://github.com/tupinek/Indent>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2005-2018 Michal Josef Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
