@@ -1,19 +1,20 @@
 #!/usr/bin/env perl
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Indent::Word;
+use Term::ANSIColor;
 
 # Object.
 my $i = Indent::Word->new(
+        'ansi' => 1,
         'line_size' => 20,
 );
 
 # Indent.
-print $i->indent(join(' ', ('text') x 7))."\n";
+print $i->indent('text text '.color('cyan').'text'.color('reset').
+        ' text '.color('red').'text'.color('reset').' text text')."\n";
 
 # Output:
 # text text text text
